===============================
pcdscalc
===============================

.. image:: https://img.shields.io/travis/pcdshub/pcdscalc.svg
        :target: https://travis-ci.org/pcdshub/pcdscalc

.. image:: https://img.shields.io/pypi/v/pcdscalc.svg
        :target: https://pypi.python.org/pypi/pcdscalc


PCDS Control-system Agnostic Calculation Routines

Documentation
-------------

https://pcdshub.github.io/pcdscalc/


Requirements
------------

* Python 3.6+
* See `requirements`_.

Installation
------------

::

    $ pip install git+https://github.com/pcdshub/pcdscalc


Running the Tests
-----------------
::

  $ pytest -vv


.. _requirements: requirements.txt
